@@ -18,7 +18,11 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
 
+#include <QFile>
+#include <QStringList>
+#include <QTextStream>
 #include <QUrl>
+
 #include <unistd.h>
 #include <sys/socket.h>
 #include <netinet/in.h>
@@ -27,9 +31,6 @@
 #include <netinet/ip.h>
 #endif
 #include <arpa/inet.h>
-#include <QStringList>
-#include <QFile>
-#include <QTextStream>
 #include <util/log.h>
 #include "upnpmcastsocket.h"
 
@@ -345,13 +346,13 @@ namespace bt
 		for (int i = 1;i < lines.count();i++)
 		{
 			line = lines[i];
-			if (line.startsWith(QLatin1String("Location")) || line.startsWith(QLatin1String("LOCATION")) || line.startsWith(QLatin1String("location")))
+			if (line.startsWith(QLatin1String("location"), Qt::CaseInsensitive))
 			{
 				location = QUrl(line.mid(line.indexOf(':') + 1).trimmed().toString()); //TODO fromLocalFile()?
 				if (!location.isValid())
 					return 0;
 			}
-			else if (line.startsWith(QLatin1String("Server")) || line.startsWith(QLatin1String("server")) || line.startsWith(QLatin1String("SERVER")))
+			else if (line.startsWith(QLatin1String("server"), Qt::CaseInsensitive))
 			{
 				server = line.mid(line.indexOf(':') + 1).trimmed().toString();
 				if (server.length() == 0)
